@@ -32,7 +32,17 @@ import colemen_utilities.string_utils as _csu
 
 
 
+FILTER = []
 
+def add_filter(value):
+    if value not in FILTER:
+        FILTER.append(value)
+
+def _contains_filter_term(value):
+    for x in FILTER:
+        if x in value:
+            return True
+    return False
 
 
 def _prepend(message,fore):
@@ -101,7 +111,15 @@ def log(
 
     if config.verbose is False:
         return None
+    if len(FILTER) > 0:
+        skip = not _contains_filter_term(message)
+        if skip is True:
+            skip = not _contains_filter_term(style)
+        if skip is True:
+            return None
 
+    
+    
     colors = [
         {
             "styles":["default","standard","white"],
@@ -213,7 +231,7 @@ def log(
 
 
     if return_string is False:
-        print(f"return_string is False")
+        # print(f"return_string is False")
         if same_line:
             print(output,end="\r",flush=True)
         else:
