@@ -4,8 +4,8 @@
 # pylint: disable=unused-import
 
 
-import colemen_utilities.database_utils.MySQL.Column.Column
-import colemen_utilities.database_utils.MySQL.Column.column_utils
+from colemen_utilities.database_utils.MySQL.Column.Column import *
+from colemen_utilities.database_utils.MySQL.Column.column_utils import *
 
 
 
