@@ -622,12 +622,13 @@ class Directory:
             `@memberOf`: File
             `@property`: drive
         '''
-        value = _obj.get_arg(self.data,['drive'],None,(str))
-        # @Mstep [IF] if the property is not currenty set
-        if value is None:
-            value = _f.get_drive(self.file_path)
-            self.data['drive'] = value
-        return value
+        # value = _obj.get_arg(self.data,['drive'],None,(str))
+        # # @Mstep [IF] if the property is not currenty set
+        # if value is None:
+        #     value = _f.get_drive(self.file_path)
+        #     self.data['drive'] = value
+        
+        return self._drive
 
 
     def create_zip(self,file_name:str = None,delete_after:bool=False,
