@@ -42,7 +42,7 @@ from threading import Thread as _Thread
 import logging as _logging
 from pathlib import Path, PureWindowsPath,PurePath
 
-from isort import file
+# from isort import file
 
 import colemen_utilities.string_utils as _csu
 import colemen_utilities.dict_utils as _obj
@@ -155,7 +155,7 @@ class File():
     _dir_path:str = None
     _access_time:int = None
     _modified_time:int = None
-    _created_time:int = None
+    _create:int = None
     _size:int = None
     _is_json:bool = False
     _content:str = None
@@ -181,7 +181,7 @@ class File():
         #     "dir_path":None,
         #     "access_time":None,
         #     "modified_time":None,
-        #     "created_time":None,
+        #     "create":None,
         #     "size":None,
         #     "is_json":None,
         # }
@@ -214,9 +214,9 @@ class File():
             "extension":self.extension,
             "name_no_ext":self.name_no_ext,
             "dir_path":self.dir_path,
-            "access_time":self.access_time,
-            "modified_time":self.modified_time,
-            "created_time":self.created_time,
+            "access_time":self.accessed,
+            "modified_time":self.modified,
+            "create":self.created,
             "drive":self.drive,
             "size":self.size,
         }
@@ -435,7 +435,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 09:15:12
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: accessed_pretty
         '''
 
@@ -454,7 +454,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 09:16:36
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: accessed_datetime
         '''
         value = datetime.fromtimestamp(self.accessed)
@@ -475,17 +475,17 @@ class File():
             `@memberOf`: File
             `@property`: created
         '''
-        value = self._created_time
+        value = self._create
         if value is None:
             value = _f.get_create_time(self.file_path,rounded=False)
-            self._created_time = value
+            self._create = value
         return value
     create_time = created
 
     @property
     def created_mdy(self):
         '''
-            Get this dir's created_timestamp as m-d-y
+            Get this dir's createstamp as m-d-y
 
             `default`:None
 
@@ -494,7 +494,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 09:15:12
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: created_pretty
         '''
 
@@ -513,7 +513,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 09:16:36
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: created_datetime
         '''
         value = datetime.fromtimestamp(self.created)
@@ -571,7 +571,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 09:15:12
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: modified_pretty
         '''
 
@@ -590,7 +590,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 09:16:36
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: modified_datetime
         '''
         value = datetime.fromtimestamp(self.modified)
@@ -616,22 +616,24 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:43:15
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: attributes
         '''
         value = self._attribs
         if value is None:
             self._gather_attributes()
+            # self._attribs = value
             value = self._attribs
         return value
 
     def _gather_attributes(self):
+        # attribs = read_or_write_attribs(self.file_path)
         self._attribs = read_or_write_attribs(self.file_path)
         # print(f"attribs:{attribs}")
-        _obj.set_attr_from_dict(self,self._attribs,set_privates=True)
-        # for k,v in self._attribs.items():
-            # if hasattr(self,f"_{k}"):
-                # setattr(self,f"_{k}",v)
+        # _obj.set_attr_from_dict(self,attribs,set_privates=True)
+        for k,v in self._attribs.items():
+            if hasattr(self,f"_{k}"):
+                setattr(self,f"_{k}",v)
 
 
     def _set_attributes(self):
@@ -658,7 +660,7 @@ class File():
     @property
     def archive(self):
         '''
-            Get this dir's archive
+            Get this file's archive attribute.
 
             `default`:None
 
@@ -667,7 +669,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: archive
         '''
         value = self._archive
@@ -678,27 +680,27 @@ class File():
             self._archive = value
         return value
 
-    @archive.setter
-    def archive(self,value):
-        '''
-            Set the File's archive property
+    # @archive.setter
+    # def archive(self,value):
+    #     '''
+    #         Set the File's archive property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: archive
-        '''
-        self._archive = value
-        if self._attribs is None:
-            self.attributes
-        self._attribs['archive'] = value
-        self._set_attributes()
-        self._attribs = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: archive
+    #     '''
+    #     self._archive = value
+    #     # if self._attribs is None:
+    #         # self.attributes
+    #     self._attribs['archive'] = value
+    #     self._set_attributes()
+    #     self._attribs = None
 
     @property
     def system(self):
@@ -712,7 +714,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: system
         '''
         value = self._system
@@ -723,27 +725,28 @@ class File():
             self._system = value
         return value
 
-    @system.setter
-    def system(self,value):
-        '''
-            Set the File's system property
+    # @system.setter
+    # def system(self,value):
+    #     '''
+    #         Set the File's system property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: system
-        '''
-        self._system = value
-        if self._attribs is None:
-            self.attributes
-        self._attribs['system'] = value
-        self._set_attributes()
-        self._attribs = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: system
+    #     '''
+    #     self._system = value
+    #     # if self._attribs is None:
+    #     #     # self._attribs = {}
+    #     #     self.attributes
+    #     self._attribs['system'] = value
+    #     self._set_attributes()
+    #     self._attribs = None
 
 
     @property
@@ -758,7 +761,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: hidden
         '''
         value = self._hidden
@@ -769,27 +772,27 @@ class File():
             self._hidden = value
         return value
 
-    @hidden.setter
-    def hidden(self,value):
-        '''
-            Set the File's hidden property
+    # @hidden.setter
+    # def hidden(self,value):
+    #     '''
+    #         Set the File's hidden property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: hidden
-        '''
-        if self._attribs is None:
-            self.attributes
-        self._attribs['hidden'] = value
-        self._set_attributes()
-        self._hidden = None
-        self._attribs = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: hidden
+    #     '''
+    #     if self._attribs is None:
+    #         self.attributes
+    #     self._attribs['hidden'] = value
+    #     self._set_attributes()
+    #     self._hidden = None
+    #     self._attribs = None
 
 
     @property
@@ -804,7 +807,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: readonly
         '''
         value = self._readonly
@@ -815,27 +818,27 @@ class File():
             self._readonly = value
         return value
 
-    @readonly.setter
-    def readonly(self,value):
-        '''
-            Set the File's readonly property
+    # @readonly.setter
+    # def readonly(self,value):
+    #     '''
+    #         Set the File's readonly property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: readonly
-        '''
-        self._readonly = value
-        if self._attribs is None:
-            self.attributes
-        self._attribs['readonly'] = value
-        self._set_attributes()
-        self._attribs = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: readonly
+    #     '''
+    #     self._readonly = value
+    #     if self._attribs is None:
+    #         self.attributes
+    #     self._attribs['readonly'] = value
+    #     self._set_attributes()
+    #     self._attribs = None
 
     @property
     def indexed(self):
@@ -849,7 +852,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: indexed
         '''
         value = self._indexed
@@ -860,27 +863,27 @@ class File():
             self._indexed = value
         return value
 
-    @indexed.setter
-    def indexed(self,value):
-        '''
-            Set the File's indexed property
+    # @indexed.setter
+    # def indexed(self,value):
+    #     '''
+    #         Set the File's indexed property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: indexed
-        '''
-        if self._attribs is None:
-            self.attributes
-        self._attribs['indexed'] = value
-        self._set_attributes()
-        self._attribs = None
-        self._indexed = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: indexed
+    #     '''
+    #     if self._attribs is None:
+    #         self.attributes
+    #     self._attribs['indexed'] = value
+    #     self._set_attributes()
+    #     self._attribs = None
+    #     self._indexed = None
 
     @property
     def encrypt(self):
@@ -894,7 +897,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: encrypt
         '''
         value = self._encrypt
@@ -905,27 +908,27 @@ class File():
             self._encrypt = value
         return value
 
-    @encrypt.setter
-    def encrypt(self,value):
-        '''
-            Set the File's encrypt property
+    # @encrypt.setter
+    # def encrypt(self,value):
+    #     '''
+    #         Set the File's encrypt property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: encrypt
-        '''
-        if self._attribs is None:
-            self.attributes
-        self._attribs['encrypt'] = value
-        self._set_attributes()
-        self._attribs = None
-        self._encrypt = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: encrypt
+    #     '''
+    #     if self._attribs is None:
+    #         self.attributes
+    #     self._attribs['encrypt'] = value
+    #     self._set_attributes()
+    #     self._attribs = None
+    #     self._encrypt = None
 
 
     @property
@@ -940,7 +943,7 @@ class File():
             ----------
             `@author`: Colemen Atwood
             `@created`: 02-23-2023 12:15:24
-            `@memberOf`: dir
+            `@memberOf`: file
             `@property`: compressed
         '''
         value = self._compressed
@@ -951,28 +954,28 @@ class File():
             self._compressed = value
         return value
 
-    @compressed.setter
-    def compressed(self,value):
-        '''
-            Set the File's compressed property
+    # @compressed.setter
+    # def compressed(self,value):
+    #     '''
+    #         Set the File's compressed property
 
-            `default`:None
+    #         `default`:None
 
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-24-2023 10:47:25
-            `@memberOf`: File
-            `@property`: compressed
-        '''
-        # self._compressed = value
-        if self._attribs is None:
-            self.attributes
-        self._attribs['compressed'] = value
-        self._set_attributes()
-        self._compressed = None
-        self._attribs = None
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 02-24-2023 10:47:25
+    #         `@memberOf`: File
+    #         `@property`: compressed
+    #     '''
+    #     # self._compressed = value
+    #     if self._attribs is None:
+    #         self.attributes
+    #     self._attribs['compressed'] = value
+    #     self._set_attributes()
+    #     self._compressed = None
+    #     self._attribs = None
 
 
 
