@@ -14,9 +14,10 @@
     `memberOf`: list_utils
 '''
 
-from typing import Iterable as _Iterable
+from typing import Iterable as _Iterable, Union
 import colemen_utilities.dict_utils as _obj
 import colemen_utilities.type_utils as _typ
+import colemen_utilities.string_utils as _csu
 
 from colemen_utilities.string_utils.string_conversion import array_to_string_list as to_string_list
 from colemen_utilities.string_utils.string_format import array_replace_string as replace_from_list
@@ -337,6 +338,112 @@ def values_to_strings(value:list,bools_to_ints=False)->list:
     '''
     return _typ.to_string(value,convert_values=True,bools_to_ints=bools_to_ints)
 
+def remove(value:list,needles:Union[str,list],starts_with:Union[str,list]=None):
+    needles = force_list(needles)
+    starts_with = force_list(starts_with,allow_nulls=False)
+    out = []
+
+    for v in value:
+        # if isinstance(v,(str)):
+        #     if len(starts_with) > 0 and isinstance(v,(str)):
+        #         skip = False
+        #         for sw in starts_with:
+        #             if v.startswith(sw):
+        #                 skip = True
+        if value not in needles:
+            skip = False
+            if len(starts_with) > 0 and isinstance(v,(str)):
+                for sw in starts_with:
+                    if v.startswith(sw):
+                        skip = True
+            if v in needles:
+                skip = True
+            if skip is False:
+                out.append(v)
+    return out
+
+
+
+
+
+def to_delimited_list(array,delimiter:str=", "):
+    '''
+        Convert a python list of values to a string of values.
+
+        This is primarily useful for templating.
+
+        ['hey',1.46,'023'] => String: 'hey',1.46,23
+
+
+        ----------
+
+        Arguments
+        -------------------------
+        `array` {list,str}
+            The list to convert
+
+        [`delimiter`=", "] {str}
+            The delimiter to use in the string.
+
+        Return {str}
+        ----------------------
+        The list converted to a string.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-17-2023 07:58:36
+        `version`: 1.0
+        `method_name`: to_delimited_list
+        * @TODO []: documentation for to_delimited_list
+    '''
+    from colemen_utilities.list_utils.list_utils import force_list
+    from colemen_utilities.validate_utils.general import numeric_only,is_integer
+    from colemen_utilities.type_utils.type_utils import to_number
+    array = force_list(array)
+    
+    vals = []
+    for x in array:
+        num = to_number(x,None)
+        if num is not None:
+            vals.append(str(num))
+            continue
+        if isinstance(x,(str)):
+            vals.append(f"'{x}'")
+    return delimiter.join(vals)
+
+
+def strip_empty_strings(value:list)->list:
+    '''
+        Strip empty string elements from a list.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {list}
+            The list to filter values from.
+
+        Return {list}
+        ----------------------
+        The list with all empty string values removed.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-03-2022 08:38:50
+        `memberOf`: objectUtils
+        `version`: 1.0
+        `method_name`: strip_list_nulls
+        * @xxx [06-03-2022 08:39:37]: documentation for strip_list_nulls
+    '''
+
+
+    if isinstance(value,(list)) is False:
+        return value
+    return [x for x in value if len(_csu.strip(x,[" "])) > 0]
+
+
 
 
 
