@@ -20,7 +20,7 @@ import exrex as _exrex
 import hashlib as _hashlib
 import time as _time
 import string as _string
-from typing import Union as _Union
+from typing import Iterable, Union as _Union
 from faker import Faker as _Faker
 from colemen_config import _os_platform,_os_divider
 import colemen_utilities.random_utils.rand_utils as _ru
@@ -64,11 +64,37 @@ def gen_variations(value):
     return varis
 
 def number(minimum=1,maximum=100):
+    if minimum > maximum:
+        maximum = minimum + maximum
     return _random.randint(minimum,maximum)
 integer = number
 
 
 def boolean(bias=50):
+    '''
+        Generate a random boolean
+        ----------
+
+        Arguments
+        -------------------------
+        [`bias`=50] {int}
+            The likelihood of this returning True
+
+            100 would always return True.
+
+
+        Return {bool}
+        ----------------------
+        The randomly selected boolean
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-15-2023 12:21:10
+        `version`: 1.0
+        `method_name`: boolean
+        * @xxx [03-15-2023 12:22:02]: documentation for boolean
+    '''
     return _random.randint(1,100) <= bias
 
 def null_boolean():
@@ -305,7 +331,7 @@ def ip_address(bias=100):
 
 host_name = faker().hostname
 '''Generate a random web host name'''
-def hostname():
+def hostname(bias=100):
     '''
         Generate a random hostname name
         ----------
@@ -323,9 +349,11 @@ def hostname():
         `method_name`: hostname
         * @xxx [03-07-2023 08:51:54]: documentation for hostname
     '''
+    if boolean(bias) is False:
+        return None
     return faker().hostname()
 
-def http_method():
+def http_method(bias=100):
     '''
         Generate a random http_method name
         ----------
@@ -343,9 +371,11 @@ def http_method():
         `method_name`: http_method
         * @xxx [03-07-2023 08:51:54]: documentation for http_method
     '''
+    if boolean(bias) is False:
+        return None
     return faker().http_method()
 
-def user_agent_chrome():
+def user_agent_chrome(bias=100):
     '''
         Generate a random user_agent_chrome name
         ----------
@@ -363,9 +393,11 @@ def user_agent_chrome():
         `method_name`: user_agent_chrome
         * @xxx [03-07-2023 08:51:54]: documentation for user_agent_chrome
     '''
+    if boolean(bias) is False:
+        return None
     return faker().chrome()
 
-def user_agent_firefox():
+def user_agent_firefox(bias=100):
     '''
         Generate a random user_agent_firefox name
         ----------
@@ -383,10 +415,12 @@ def user_agent_firefox():
         `method_name`: user_agent_firefox
         * @xxx [03-07-2023 08:51:54]: documentation for user_agent_firefox
     '''
+    if boolean(bias) is False:
+        return None
     return faker().firefox()
 
 
-def user_agent_internet_explorer():
+def user_agent_internet_explorer(bias=100):
     '''
         Generate a random user_agent_internet_explorer name
         ----------
@@ -404,10 +438,12 @@ def user_agent_internet_explorer():
         `method_name`: user_agent_internet_explorer
         * @xxx [03-07-2023 08:51:54]: documentation for user_agent_internet_explorer
     '''
+    if boolean(bias) is False:
+        return None
     return faker().internet_explorer()
 
 
-def user_agent_opera():
+def user_agent_opera(bias=100):
     '''
         Generate a random user_agent_opera name
         ----------
@@ -425,9 +461,11 @@ def user_agent_opera():
         `method_name`: user_agent_opera
         * @xxx [03-07-2023 08:51:54]: documentation for user_agent_opera
     '''
+    if boolean(bias) is False:
+        return None
     return faker().opera()
 
-def user_agent_safari():
+def user_agent_safari(bias=100):
     '''
         Generate a random user_agent_safari name
         ----------
@@ -445,9 +483,11 @@ def user_agent_safari():
         `method_name`: user_agent_safari
         * @xxx [03-07-2023 08:51:54]: documentation for user_agent_safari
     '''
+    if boolean(bias) is False:
+        return None
     return faker().safari()
 
-def user_agent():
+def user_agent(bias=100):
     '''
         Generate a random user_agent name
         ----------
@@ -465,6 +505,8 @@ def user_agent():
         `method_name`: user_agent
         * @xxx [03-07-2023 08:51:54]: documentation for user_agent
     '''
+    if boolean(bias) is False:
+        return None
     return faker().user_agent()
 
 
@@ -1507,5 +1549,83 @@ latitude = faker().latitude()
 longitude = faker().longitude()
 '''Randomly generate a longitudinal coordinate'''
 
+def http_status_code(bias:int=100)->int:
+    '''
+        Generate a random HTTP status code.
+        ----------
+
+        Arguments
+        -------------------------
+
+        [`bias`=100] {int}
+            The likelihood (0-100) of it returning an value vs returning None
+
+            If bias = 100 it will always return a value and never None.
+
+        Return {int,None}
+        ----------------------
+        A random status code or None
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-15-2023 12:09:08
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: http_status_code
+        * @xxx [03-15-2023 12:10:29]: documentation for http_status_code
+    '''
+    valid_status_codes = ["100","101","102","103","200","201","202","203","204","205","206","207","208","226","300","301","302","303","304","305","306","307","308","400","401","402","403","404","405","406","407","408","409","410","411","412","413","414","415","416","417","418","421","422","423","424","425","426","428","429","431","451","500","501","502","503","504","505","506","507","508","510","511"]
+    if faker().boolean(bias):
+        return int(_ru.option(valid_status_codes))
+    return None
 
 
+def http_request_method(bias:int=100)->str:
+    '''
+        Generate a random HTTP request method.
+        ----------
+
+        Arguments
+        -------------------------
+
+        [`bias`=100] {int}
+            The likelihood (0-100) of it returning an value vs returning None
+
+            If bias = 100 it will always return a value and never None.
+
+        Return {str,None}
+        ----------------------
+        A random request method or None
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-15-2023 12:09:08
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: http_request_method
+        * @xxx [03-15-2023 12:10:29]: documentation for http_request_method
+    '''
+    valid_request_methods = ["connect","delete","get","head","options","patch","post","put","trace"]
+    if faker().boolean(bias):
+        return _ru.option(valid_request_methods)
+    return None
+
+
+def list_of_strings(length=3,bias:int=100)->Iterable[str]:
+    out = []
+    for x in range(length):
+        out.append(abstract_name())
+    return out
+def list_of_integers(length=3,minimum=1,maximum=100,exclude=None,bias:int=100)->Iterable[str]:
+    out = []
+    for x in range(length):
+        out.append(number(minimum,maximum))
+    if isinstance(exclude,(list)):
+        no = []
+        for o in out:
+            if o not in exclude:
+                no.append(o)
+        out = no
+    return out
