@@ -18,6 +18,7 @@
 # import json
 # import hashlib
 import logging as _logging
+from pathlib import Path, PurePath
 import colemen_config as _config
 from typing import Union as _Union
 import re as _re
@@ -586,7 +587,15 @@ def extension(string:_Union[str,list])->_Union[str,list]:
     return new_ext_array
 format_extension = extension
 
-def file_path(value:str, **kwargs)->str:
+def file_path(
+    value:str,
+    strip_trailing_separator:bool=True,
+    escape_spaces:bool=False,
+    url:bool=False,
+    url_encode:bool=False,
+    url_decode:bool=False,
+    # **kwargs
+    )->str:
     '''
         Formats the path for use in windows.
 
@@ -597,8 +606,6 @@ def file_path(value:str, **kwargs)->str:
         `value` {str}
             The file path to format.
 
-        Keyword Arguments
-        -------------------------
         [`strip_trailing_separator`=True] {bool}
             if False, the path is allowed to end with a trailing separator.
 
@@ -615,6 +622,7 @@ def file_path(value:str, **kwargs)->str:
             If True the url is has all special characters decoded.
 
 
+
         Return {str}
         ----------------------
         The formatted file path.
@@ -627,13 +635,16 @@ def file_path(value:str, **kwargs)->str:
         `version`: 1.0
         `method_name`: file_path
     '''
-    strip_trailing_separator = _obj.get_kwarg(["strip_trailing_separator"], True, (bool), **kwargs)
-    treat_as_url = _obj.get_kwarg(["url"], False, (bool), **kwargs)
-    escape_spaces = _obj.get_kwarg(["escape spaces"], False, (bool), **kwargs)
+    # strip_trailing_separator = _obj.get_kwarg(["strip_trailing_separator"], True, (bool), **kwargs)
+    # treat_as_url = _obj.get_kwarg(["url"], False, (bool), **kwargs)
+    treat_as_url = url
+    # escape_spaces = _obj.get_kwarg(["escape spaces"], False, (bool), **kwargs)
     path_sep = escape_regex(_os.path.sep)
     if treat_as_url is True:
-        return url(value, **kwargs)
+        return format_url(value, url_encode=url_encode,url_decode=url_decode,strip_trailing_separator=strip_trailing_separator)
     # print(f"path_sep: {path_sep}")
+    
+    value = PurePath(Path(value)).as_posix()
     value = _re.sub(r'(\\|\/)', path_sep, value)
     regex = _re.compile(rf'{path_sep}+')
     value = _re.sub(regex, path_sep, value)
@@ -656,7 +667,7 @@ def file_path(value:str, **kwargs)->str:
     return value
 format_file_path = file_path
 
-def url(value:str, **kwargs)->str:
+def url(value:str,url_encode:bool=False,url_decode:bool=False,strip_trailing_separator:bool=True)->str:
     '''
         Formats a url string
 
@@ -667,8 +678,6 @@ def url(value:str, **kwargs)->str:
         `value` {str}
             The url to format
 
-        Keyword Arguments
-        -------------------------
         [`encode`=False] {bool}
             If True the url is has all special characters encoded.
 
@@ -690,9 +699,12 @@ def url(value:str, **kwargs)->str:
         `version`: 1.0
         `method_name`: url
     '''
-    strip_trailing_separator = _obj.get_kwarg(["strip_trailing_separator"], True, (bool), **kwargs)
-    encode = _obj.get_kwarg(["encode", "url_encode"], False, (bool), **kwargs)
-    decode = _obj.get_kwarg(["decode", "url_decode"], False, (bool), **kwargs)
+    # strip_trailing_separator = _obj.get_kwarg(["strip_trailing_separator"], True, (bool), **kwargs)
+    strip_trailing_separator = strip_trailing_separator
+    encode = url_encode
+    # encode = _obj.get_kwarg(["encode", "url_encode"], False, (bool), **kwargs)
+    decode = url_decode
+    # decode = _obj.get_kwarg(["decode", "url_decode"], False, (bool), **kwargs)
     path_sep = "/"
     value = _re.sub(r'(\\|\/)', path_sep, value)
     regex = _re.compile(rf'{path_sep}+')
@@ -757,7 +769,7 @@ def strip_empty_lines(value:str)->str:
 
 
 
-def array_in_string(array, value, default=False):
+def array_in_string(array, value, default=False)->bool:
     '''
         iterates the array provided checking if any element exists in the value.
 
@@ -831,6 +843,8 @@ def array_replace_string(value,needles, new_string="", **kwargs):
         `version`: 1.0
         `method_name`: array_replace_string
     '''
+    if isinstance(needles,(dict)):
+        return dict_replace_string(value,needles)
     max_replace = _obj.get_kwarg(['max','max replace'],0,(int),**kwargs)
     if len(needles) == 0:
         return value
@@ -855,6 +869,11 @@ def dict_replace_string(value:str,replace:dict):
     '''
         Replace all keys with their values in the value string.
 
+        This replacement method will keep replacing until it finds no matches.
+        That essentially means that if a previous replacement changes the value that matches a 
+        different replacement, it will then replace that value and will continue doing so until 
+        there are no more matches.
+
         ----------
 
         Arguments
@@ -882,14 +901,21 @@ def dict_replace_string(value:str,replace:dict):
         * @xxx [06-29-2022 05:17:05]: documentation for dict_replace_string
     '''
 
-
     if isinstance(replace,(dict)) is False:
         _con.log("The replace argument must be a dictionary","error")
         return None
     
-    for k,v in replace.items():
-        if v is not None:
-            value = value.replace(k,v)
+    match_found = True
+    # @Mstep [LOOP] while there are matches still in the value
+    while match_found is True:
+        match_found = False
+        # @Mstep [loop] iterate the replacements
+        for k,v in replace.items():
+            if v is not None:
+                new_val = value.replace(k,v)
+                if new_val != value:
+                    value = new_val
+                    match_found = True
     return value
 
 def plural_noun(value:str):
@@ -950,3 +976,53 @@ def singular_noun(value:str):
 
     p = _config.inflect_engine()
     return p.singular_noun(value)
+
+
+def replace_end(subject,target,replace=""):
+    '''
+        Replace a substring from the end of the subject.
+        ----------
+
+        Arguments
+        -------------------------
+        `subject` {str}
+            The string to perform the replacement on.
+        `target` {str}
+            The value to search for in the subject
+        [`replace`=""] {str}
+            The value to replace the target with.
+
+
+        Return {str}
+        ----------------------
+        The subject with the target replaced if it is found.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 11-29-2022 11:02:07
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: replace_end
+        * @xxx [11-29-2022 11:06:10]: documentation for replace_end
+    '''
+    tlen = len(target)
+    # @Mstep [if] if the subject is less than the target
+    if len(subject) < tlen:
+        # @Mstep [RETURN] return the subject.
+        return subject
+    # @Mstep [] get the last n characters of the subject
+    last = subject[tlen*-1:].lower()
+    # @Mstep [IF] if the target ends with the last string.
+    if last == target.lower():
+        # @Mstep [] get the precedeing characters
+        value = subject[:tlen*-1]
+        # @Mstep [] concatenate the replace onto the value
+        value = f"{value}{replace}"
+        # @Mstep [RETURN] return the value
+        return value
+    # @Mstep [RETURN] return the subject.
+    return subject
+
+
+
