@@ -17,11 +17,13 @@
 
 import json as _json
 import hashlib as _hashlib
+import exrex as _exrex
 # import string
 # import random
 # from faker import Faker
 import colemen_utilities.dict_utils as _obj
 import colemen_utilities.string_utils as _csu
+from colemen_utilities.random_utils.rand_utils import option as _rand_option
 # from colemen_utilities.dict_utils.dict_utils import get_kwarg as _obj.get_kwarg
 # from colemen_utilities.string_utils.string_format import to_snake_case as _csu.to_snake_case
 # from colemen_utilities.string_utils.string_format import to_screaming_snake as _csu.to_screaming_snake
@@ -419,6 +421,8 @@ def replace_at(s, newstring, index, nofail=False):
     return s[:index] + newstring + s[index + 1:]
 
 
+def exrex_extrapolation(base:str):
+    return _rand_option(list(_exrex.generate(base)))    
 
 
 
